clc 
clear all

%% Umbilical properties
%1. Outer Sheat
OD_p1 = 0.143;          % OD outer sheat
ID_p1 = 0.134;
rm_1 = (OD_p1 + ID_p1)/4;
t_p1 = (OD_p1 - ID_p1)/4;

%Armouring layer 
OD_a1 = 4e-3;           %Outer armour
OD_a2 = OD_a1;          % Inner armour
n_a1 = 95;
n_a2 = 87;
rm_a1 = (ID_p1 - OD_a1)/2;
rm_a2 = (ID_p1 - 2*OD_a2)/2;

%Inner plastic sheat 
OD_p2 = 0.117;
ID_p2 = 0.11;
rm_3 = (OD_p2 + ID_p2)/4;

%Steel tubes
OD_s1 = 0.022;
ID_s1 = 0.018;
rm_s1 = 0.033;
n_1 = 6;
n_2 = 5;
  
%Steel core
OD_c = 0.022;           
ID_c = 0.018;
rm_c = (OD_c + ID_c)/4;
t_c = (OD_c - ID_c)/2;

t_p2 = (OD_p2 - ID_p2)/2;
t_s1 = (OD_s1 - ID_s1)/2;
%% Cross-section areas
A_1 = pi/4*(OD_p1^2 - ID_p1^2);
A_2 = pi/4*(OD_a1^2);
A_3 = pi/4*(OD_a2^2);
A_a = A_2 + A_3;

A_4 = pi/4*(OD_p2^2 - ID_p2^2);
A_5 = pi/4*(OD_s1^2 - ID_s1^2);
A_6 = pi/4*(OD_c^2 - ID_c^2);

A_t = A_1 + A_2 + A_3 + A_4 + A_5 + A_6;

alpha = 5*2*pi/360;

n = 5;

%% Moments of inertia
I_1 = pi/64*(OD_p1^4 - ID_p1^4);
I_2 = pi*(OD_a1)^4/4; 
I_3 = pi*(OD_a2)^4/4;
I_4 = pi/64*(OD_p2^4 - ID_p2^4);
I_5 = pi/64*(OD_s1^4 - ID_s1^4); 
I_6 = pi/64*(OD_c^4 - ID_c^4);

J_1 = 2*I_1;
J_2 = 2*I_2;
J_3 = 2*I_3;
J_4 = 2*I_4;
J_5 = 2*I_5;
J_6 = 2*I_6;

%% Material properties
E_st = 2e11;                   %E-modulus steel                  
E_os  = 3e8;                  % E-modulus outer sheat
E_in = 3e8;                % E-modulus XLPE
E_helix = 2e11;

G_st = E_st/(2*(1+0.3));
G_os = E_os/(2*(1+0.3));
%% Clamp pressure

sigma_F = 20e6;
p_os = sigma_F *(t_p1/(OD_p1/2));

q3_1 = p_os*2*pi*rm_1*cos(alpha);

q3_2 = p_os*2*pi*rm_1*cos(alpha)/95;

q3_3 = p_os*2*pi*rm_1*cos(alpha)/85;

q3_4 = p_os*2*pi*rm_1*cos(alpha)/6;

q3_5 = p_os*2*pi*rm_1*cos(alpha)/5;

my =0.3;

%beta_2c_1 = (my*(q3_1*2))/(E_os*A_p1*(cos(alpha))^2*sin(alpha));
beta_2c_2 = (my*(2*q3_2))/(E_st*A_2*(cos(alpha))^2*sin(alpha));
beta_2c_3 = (my*(2*q3_3))/(E_st*A_3*(cos(alpha))^2*sin(alpha));
beta_2c_4 = (my*(2*q3_4)/(E_st*A_5*(cos(alpha))^2*sin(alpha)));
beta_2c_5 = (my*(2*q3_5)/(E_st*A_6*(cos(alpha))^2*sin(alpha)));


beta_12 = (4/pi)*beta_2c_2;
beta_2 = (4/pi)*beta_2c_3;
beta_3 = (4/pi)*beta_2c_4;
beta_4 = (4/pi)*beta_2c_5;

beta = [beta_12 beta_2 beta_3 beta_4];
beta_1 = sort(beta);

F_f1 = 1.0; %Helix
F_f2 = 0.9; %Armouring 


EI_e = E_os*I_1 + E_in*I_4 + 0.5*(n_a1*(G_st*J_2*4*sin(alpha)^2*cos(alpha) + E_st*I_2*((cos(alpha)^3)*cos(2*alpha)^2) + E_st*I_2*cos(alpha)*(1 + 2*sin(alpha)^2+sin(alpha)^4)))+0.5*(n_a2*(G_st*J_3*4*sin(alpha)^2*cos(alpha) + E_st*I_3*((cos(alpha)^3)*cos(2*alpha)^2 + cos(alpha)*(1 + 2*sin(alpha)^2+sin(alpha)^4))))+0.5*((G_st*J_6*4*sin(alpha)^2*cos(alpha) + E_st*I_6*((cos(alpha)^3)*cos(2*alpha)^2) + E_st*I_6*cos(alpha)*(1 + 2*sin(alpha)^2+sin(alpha)^4))) + (n_1+n_2)*E_st*I_5; %0.5*(n_1+n_2)*((G_st*J_5*4*sin(25*2*pi/360)^2*cos(25*2*pi/360) + E_st*I_5*((cos(25*2*pi/360)^3)*cos(2*25*2*pi/360)^2) + E_st*I_5*cos(25*2*pi/360)*(1 + 2*sin(25*2*pi/360)^2+sin(25*2*pi/360)^4)));

t_eff3 = n_a1*A_2/(2*pi*rm_a1);
t_eff4 = n_a2*A_3/(2*pi*rm_a1);


EI_s1 = E_st*pi*rm_a1^3*F_f2*t_eff3*cos(alpha)^4;

EI_s2 = E_st*pi*rm_a2^3*F_f2*t_eff4*cos(alpha)^4; 

EI_s3 = E_helix*0.5*11*A_5*rm_s1^2*F_f1*cos(alpha)^4 ;

EI_s4 = E_helix*0.5*A_6*rm_c^2*F_f1*cos(alpha)^4;


k=0.0:0.0001:0.1;

for i = 1:length(k)
    if k(i)<=beta_1(1)     
        Mf_s1(i) = EI_s1*k(i);
        Mf_s2(i) = EI_s2*k(i);
        Mf_s3(i) = EI_s3*k(i);
        Mf_s4(i) = EI_s4*k(i);
        
    elseif k(i)<beta_1(2)
        if k(i)>beta_1(1)
            Mf_s1(i) = Mf_s1(i-1);
            Mf_s2(i) = EI_s2*k(i);
            Mf_s3(i) = EI_s3*k(i);
            Mf_s4(i) = EI_s4*k(i);        
        end
    elseif k(i)<=beta_1(3)
        if k(i) > beta_1(2)
            Mf_s1(i) = Mf_s1(i-1);
            Mf_s2(i) = Mf_s2(i-1);
            Mf_s3(i) = EI_s3*k(i);
            Mf_s4(i) = EI_s4*k(i); 
        end
    elseif k(i) <= beta_1(4)
        if k(i) > beta_1(3)
            Mf_s1(i) = Mf_s1(i-1);
            Mf_s2(i) = Mf_s2(i-1);
            Mf_s3(i) = Mf_s3(i-1);
            Mf_s4(i) = EI_s4*k(i); 
        end
    else
            Mf_s1(i) = Mf_s1(i-1);
            Mf_s2(i) = Mf_s2(i-1);
            Mf_s3(i) = Mf_s3(i-1);
            Mf_s4(i) = Mf_s4(i-1);
            
    end    
end

Mf_e = EI_e*k;

Mf = Mf_s1 + Mf_s2 + Mf_s3 + Mf_s4 + Mf_e;

plot(k,Mf)
xlabel('Curvature [1/m]');
ylabel('Bending Moment [Nm]');
title('Moment-curvature relation');
ans = [Mf(35), Mf(39), Mf(54),Mf(65),Mf(1001)]
% %% Axial stiffness
% v_a = 0.3;
% EA = 2*pi*((rm_h1+rm_h2)/2)*(t_a1+t_a2)*F_f1*E_st*(cos(alpha)^2*(cos(alpha)^2 - v_a*sin(alpha)^2));
% 
% %% Torsional stiffness
% GI = E_st*2*pi*((rm_h1+rm_h2)/2)^3*(t_a1+t_a2)*F_f1*sin(alpha)^2*cos(alpha)^2;